==> pydantic_dydb-0.1.1.tar.gz: pydantic_dydb-0.1.1/pydantic_dydb/aws.py <==
from urllib.parse import urlparse

import orjson
import requests
from aws_requests_auth.aws_auth import AWSRequestsAuth

from .credentials_managers import CredentialManagerBase

# api https://docs.aws.amazon.com/amazondynamodb/latest/APIReference

throwaway_value = ""


def _set_target(action: str):
    return {"X-Amz-Target": f"DynamoDB_20120810.{action}"}


class DynamoDB:
    DESCRIBE_TABLE_TARGET = _set_target("DescribeTable")
    GET_TARGET = _set_target("GetItem")
    PUT_TARGET = _set_target("PutItem")
    QUERY_TARGET = _set_target("Query")
    SCAN_TARGET = _set_target("Scan")
    DELETE_TARGET = _set_target("DeleteItem")
    BATCH_GET_TARGET = _set_target("BatchGetItem")
    BATCH_WRITE_TARGET = _set_target("BatchWriteItem")
    # CREATE_TABLE_TARGET = _set_target("CreateTable")

    def __init__(
        self,
        *,
        table_name: str,
        credential_manager: CredentialManagerBase,
        region: str,
        endpoint: str,
    ):
        self.__credential_manager = credential_manager

        self._url = endpoint
        self._netlock = urlparse(self._url).netloc

        self._s = requests.Session()
        self._s.headers.update({"Content-Type": "application/json"})
        self._table_name = table_name
        self._region = region

    def _get_aws_auth(self):
        creds = self.__credential_manager.get_credentials()
        auth_dict = dict(
            aws_access_key=creds.aws_access_key.get_secret_value(),
            aws_secret_access_key=creds.aws_secret_key.get_secret_value(),
            aws_host=self._netlock,
            aws_region=self._region,
            aws_service="dynamodb",
        )
        if creds.aws_session_token:
            auth_dict["aws_token"] = creds.aws_session_token.get_secret_value()
        return AWSRequestsAuth(**auth_dict)

    def describe_table(self):
        body = {"TableName": self._table_name}
        resp = self._s.post(
            self._url,
            data=orjson.dumps(body),
            headers=self.DESCRIBE_TABLE_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def get_item(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.GET_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def put_item(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.PUT_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def query(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.QUERY_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def scan(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.SCAN_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def batch_get(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.BATCH_GET_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def batch_write(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.BATCH_WRITE_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def delete(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.DELETE_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    # def create_table(self, **kwargs):
    #     resp = self._s.post(
    #         self._url,
    #         data=orjson.dumps(kwargs),
    #         headers=self.CREATE_TABLE_TARGET,
    #         auth=self._get_aws_auth(),
    #     )
    #     resp.raise_for_status()
    #     return resp.content

==> pydantic_dydb-0.1.2.tar.gz: pydantic_dydb-0.1.2/pydantic_dydb/aws.py <==
from urllib.parse import urlparse

import orjson
import requests
from aws_requests_auth.aws_auth import AWSRequestsAuth

from .credentials_managers import CredentialManagerBase

# api https://docs.aws.amazon.com/amazondynamodb/latest/APIReference


def _set_target(action: str):
    return {"X-Amz-Target": f"DynamoDB_20120810.{action}"}


class DynamoDB:
    DESCRIBE_TABLE_TARGET = _set_target("DescribeTable")
    GET_TARGET = _set_target("GetItem")
    PUT_TARGET = _set_target("PutItem")
    QUERY_TARGET = _set_target("Query")
    SCAN_TARGET = _set_target("Scan")
    DELETE_TARGET = _set_target("DeleteItem")
    BATCH_GET_TARGET = _set_target("BatchGetItem")
    BATCH_WRITE_TARGET = _set_target("BatchWriteItem")
    # CREATE_TABLE_TARGET = _set_target("CreateTable")

    def __init__(
        self,
        *,
        table_name: str,
        credential_manager: CredentialManagerBase,
        region: str,
        endpoint: str,
    ):
        self.__credential_manager = credential_manager

        self._url = endpoint
        self._netlock = urlparse(self._url).netloc

        self._s = requests.Session()
        self._s.headers.update({"Content-Type": "application/json"})
        self._table_name = table_name
        self._region = region

    def _get_aws_auth(self):
        creds = self.__credential_manager.get_credentials()
        return AWSRequestsAuth(
            aws_access_key=creds.aws_access_key,
            aws_secret_access_key=creds.aws_secret_key,
            aws_host=self._netlock,
            aws_region=self._region,
            aws_service="dynamodb",
            aws_token=creds.aws_session_token,
        )

    def describe_table(self):
        body = {"TableName": self._table_name}
        resp = self._s.post(
            self._url,
            data=orjson.dumps(body),
            headers=self.DESCRIBE_TABLE_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def get_item(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.GET_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def put_item(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.PUT_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def query(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.QUERY_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def scan(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.SCAN_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def batch_get(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.BATCH_GET_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def batch_write(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.BATCH_WRITE_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    def delete(self, **kwargs):
        resp = self._s.post(
            self._url,
            data=orjson.dumps(kwargs),
            headers=self.DELETE_TARGET,
            auth=self._get_aws_auth(),
        )
        resp.raise_for_status()
        return resp.content

    # def create_table(self, **kwargs):
    #     resp = self._s.post(
    #         self._url,
    #         data=orjson.dumps(kwargs),
    #         headers=self.CREATE_TABLE_TARGET,
    #         auth=self._get_aws_auth(),
    #     )
    #     resp.raise_for_status()
    #     return resp.content
